package com.example.backend.services;

import com.example.backend.User;
import com.example.backend.UserRepository;
import com.example.backend.exceptions.UserNotFoundException;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.stereotype.Service;

@Service
public class UserService {

    private final UserRepository userRepository;
    private final PasswordEncoder passwordEncoder;

    // Dependency Injection (Spring kümmert sich darum)
    public UserService(UserRepository userRepository) {
        this.userRepository = userRepository;
        this.passwordEncoder = new BCryptPasswordEncoder(); // Initialisierung von BCrypt
    }

    // Neuen Benutzer erstellen (mit Passwort-Hashing)
    public User createUser(User user) {
        user.setPassword(passwordEncoder.encode(user.getPassword())); // Passwort hashen
        return userRepository.save(user);
    }

    // Benutzer anhand des Benutzernamens suchen
    public User getUserByUsername(String username) {
        return userRepository.findByUsername(username).orElse(null);
    }

    // Benutzer anhand der E-Mail suchen
    public User getUserByEmail(String email) {
        return userRepository.findByEmail(email).orElseThrow(()->new UserNotFoundException("User not found: "+email));
    }

    // Passwort überprüfen
    public boolean checkPassword(String rawPassword, String hashedPassword) {
        return passwordEncoder.matches(rawPassword, hashedPassword);
    }
    public User updateUser(String email, User updatedUser) {
        User existingUser = userRepository.findByEmail(email)
                .orElseThrow(() -> new UserNotFoundException("User not found: "+email));

        existingUser.setUsername(updatedUser.getUsername());
        // Weitere Felder falls nötig

        return userRepository.save(existingUser);
    }

}
