import {BrowserRouter as Router, Routes, Route, Navigate} from "react-router-dom";

// Screens (du musst diese entsprechend importieren)
import ProfileScreen from "./screens/Profile";
import EditProfileScreen from "./screens/EditProfileScreen";
import LibraryScreen from "./screens/LibraryScreen";
import RegistrationScreen from "./screens/RegisterScreen";
import LoginScreen from "./screens/LoginScreen";
import HomeScreen from "./screens/Home.tsx";
import type {JSX} from "react";

// Optional: Auth-Gateway (z. B. ProtectedRoute)
const isAuthenticated = () => {
    return localStorage.getItem("authToken") !== null;
};

const ProtectedRoute = ({children}: { children: JSX.Element }) => {
    return isAuthenticated() ? children : <Navigate to="/login"/>;
};

const App = () => {
    return (
        <Router>
            <Routes>
                {/* Öffentliche Seiten */}
                <Route path="/login" element={<LoginScreen/>}/>
                <Route path="/register" element={<RegistrationScreen/>}/>

                {/* Geschützte Seiten */}
                <Route
                    path="/profile"
                    element={
                        <ProtectedRoute>
                            <ProfileScreen/>
                        </ProtectedRoute>
                    }
                />
                <Route
                    path="/edit-profile"
                    element={
                        <ProtectedRoute>
                            <EditProfileScreen/>
                        </ProtectedRoute>
                    }
                />
                <Route
                    path="/library/:userId"
                    element={
                        <ProtectedRoute>
                            <LibraryScreen/>
                        </ProtectedRoute>
                    }
                />
                <Route
                    path="/recipes/:id"
                    element={
                        <ProtectedRoute>
                            <HomeScreen/>
                        </ProtectedRoute>
                    }
                />

                {/* Fallback/Redirect */}
                <Route path="*" element={<Navigate to="/profile"/>}/>
            </Routes>
        </Router>
    );
};

export default App;
