import React, { useState, useEffect } from "react";
import { jwtDecode } from "jwt-decode";
import { useNavigate } from "react-router-dom";

const API_URL = "http://localhost:8080/users"; // localhost für Web (kein 10.0.2.2)

const EditProfileScreen = () => {
    const [username, setUsername] = useState("");
    const [email, setEmail] = useState("");
    const [loading, setLoading] = useState(true);
    const navigate = useNavigate();

    useEffect(() => {
        const fetchUserProfile = async () => {
            try {
                const token = localStorage.getItem("authToken");
                if (!token) return;

                const decoded: any = jwtDecode(token);
                const userEmail = decoded.sub;

                const response = await fetch(`${API_URL}/email/${userEmail}`, {
                    headers: {
                        Authorization: `Bearer ${token}`,
                        "Content-Type": "application/json",
                    },
                });

                if (!response.ok) throw new Error("Fehler beim Laden");

                const data = await response.json();
                setUsername(data.username);
                setEmail(data.email);
            } catch (error) {
                console.error("Fehler beim Laden:", error);
                alert("Profil konnte nicht geladen werden.");
            } finally {
                setLoading(false);
            }
        };

        fetchUserProfile();
    }, []);

    const handleSave = async () => {
        if (!email) return;

        try {
            const token = localStorage.getItem("authToken");

            const response = await fetch(`${API_URL}/update/email/${email}`, {
                method: "PUT",
                headers: {
                    Authorization: `Bearer ${token}`,
                    "Content-Type": "application/json",
                },
                body: JSON.stringify({ username, email }),
            });

            if (!response.ok) throw new Error("Fehler beim Speichern");

            alert("Änderungen gespeichert.");
            navigate(-1); // Zurück
        } catch (error) {
            console.error("Fehler beim Speichern:", error);
            alert("Profil konnte nicht gespeichert werden.");
        }
    };

    if (loading) return <p>Lade Profil...</p>;

    return (
        <div style={styles.container}>
            <label style={styles.label}>Benutzername</label>
            <input
                type="text"
                value={username}
                onChange={(e) => setUsername(e.target.value)}
                style={styles.input}
                placeholder="Benutzername"
            />

            <label style={styles.label}>E-Mail</label>
            <input
                type="email"
                value={email}
                readOnly
                style={{ ...styles.input, backgroundColor: "#f0f0f0" }}
            />

            <button onClick={handleSave} style={styles.button}>
                Speichern
            </button>
        </div>
    );
};

const styles: { [key: string]: React.CSSProperties } = {
    container: {
        maxWidth: "400px",
        margin: "50px auto",
        padding: "20px",
        border: "1px solid #ccc",
        borderRadius: "8px",
        backgroundColor: "#fff",
        boxShadow: "0 0 10px rgba(0,0,0,0.1)",
    },
    label: {
        display: "block",
        fontSize: "16px",
        marginBottom: "5px",
    },
    input: {
        width: "100%",
        padding: "10px",
        marginBottom: "15px",
        border: "1px solid #ccc",
        borderRadius: "5px",
    },
    button: {
        width: "100%",
        padding: "12px",
        backgroundColor: "#007bff",
        color: "#fff",
        border: "none",
        borderRadius: "5px",
        fontSize: "16px",
        cursor: "pointer",
    },
};

export default EditProfileScreen;
