import React, { useEffect, useState } from "react";
import { useNavigate, useParams } from "react-router-dom";
import axios from "axios";

interface Recipe {
    id: number;
    name: string;
    category: string;
}

const LibraryScreen = () => {
    const [favorites, setFavorites] = useState<Recipe[]>([]);
    const [ownRecipes, setOwnRecipes] = useState<Recipe[]>([]);
    const [loading, setLoading] = useState(true);
    const navigate = useNavigate();
    const { userId } = useParams<{ userId: string }>(); // expects userId from route like /library/:userId

    useEffect(() => {
        fetchRecipes();
    }, []);

    const fetchRecipes = async () => {
        try {
            const favoriteResponse = await axios.get(`http://localhost:8080/api/recipes/favorites/${userId}`);
            const ownResponse = await axios.get(`http://localhost:8080/api/recipes/user/${userId}`);

            setFavorites(favoriteResponse.data);
            setOwnRecipes(ownResponse.data);
        } catch (error) {
            console.error("Fehler beim Laden der Rezepte:", error);
        } finally {
            setLoading(false);
        }
    };

    const renderRecipe = (recipe: Recipe) => (
        <div
            key={recipe.id}
            onClick={() => navigate(`/recipes/${recipe.id}`)}
            style={styles.recipeCard}
        >
            <h4 style={{ margin: 0 }}>{recipe.name}</h4>
            <p style={{ margin: 0, color: "#555" }}>{recipe.category}</p>
        </div>
    );

    if (loading) {
        return <div style={styles.loading}>Lade Rezepte...</div>;
    }

    return (
        <div style={styles.container}>
            <h2>Favorisierte Rezepte</h2>
            {favorites.length === 0 ? (
                <p>Keine Favoriten gefunden.</p>
            ) : (
                favorites.map(renderRecipe)
            )}

            <h2 style={{ marginTop: 30 }}>Eigene Rezepte</h2>
            {ownRecipes.length === 0 ? (
                <p>Du hast noch keine eigenen Rezepte.</p>
            ) : (
                ownRecipes.map(renderRecipe)
            )}

            <button style={styles.createButton} onClick={() => navigate("/create-recipe")}>
                Neues Rezept erstellen
            </button>
        </div>
    );
};

const styles: { [key: string]: React.CSSProperties } = {
    container: {
        maxWidth: 800,
        margin: "40px auto",
        padding: 20,
        fontFamily: "Arial, sans-serif",
    },
    loading: {
        textAlign: "center",
        padding: 40,
        fontSize: 18,
    },
    recipeCard: {
        borderBottom: "1px solid #ddd",
        padding: "10px 0",
        cursor: "pointer",
    },
    createButton: {
        marginTop: 30,
        padding: "12px 20px",
        backgroundColor: "#007bff",
        color: "white",
        border: "none",
        borderRadius: 5,
        fontSize: 16,
        cursor: "pointer",
    },
};

export default LibraryScreen;
