import { useState } from "react";
import { useNavigate } from "react-router-dom";
import { loginUser } from "../services/authService";
import { colors, spacing, radii, fontSizes } from "../theme";

const LoginScreen = () => {
    const [email, setEmail] = useState("");
    const [password, setPassword] = useState("");
    const navigate = useNavigate();

    const handleLogin = async () => {
        try {
            const token = await loginUser(email, password);
            if (token) {
                console.log("Login erfolgreich!", token);

                // Token im localStorage speichern (Web)
                localStorage.setItem("authToken", token);

                // Navigation zur Home-Seite
                navigate("/home");
            } else {
                console.log("Login fehlgeschlagen");
            }
        } catch (error) {
            console.error("Fehler beim Login:", error);
        }
    };

    return (
        <div style={styles.wrapper}>
            <div style={styles.container}>
                <h2 style={styles.title}>Login</h2>

                <input
                    type="email"
                    placeholder="E-Mail"
                    value={email}
                    onChange={(e) => setEmail(e.target.value)}
                    style={styles.input}
                />

                <input
                    type="password"
                    placeholder="Passwort"
                    value={password}
                    onChange={(e) => setPassword(e.target.value)}
                    style={styles.input}
                />

                <button onClick={handleLogin} style={styles.button}>
                    Einloggen
                </button>

                <p style={styles.linkText} onClick={() => navigate("/register")}>
                    Noch kein Konto? Registrieren
                </p>
            </div>
        </div>
    );
};

const styles: { [key: string]: React.CSSProperties } = {
    wrapper: {
        display: "flex",
        alignItems: "center",
        justifyContent: "center",
        height: "100vh",           // ganzer Viewport
        width: "100vw",
        backgroundColor: colors.background, // optional für Theme-Kontrast
    },
    container: {
        display: "flex",
        flexDirection: "column",
        justifyContent: "center",
        maxWidth: "400px",
        width: "90%",
        margin: "10vh auto",
        padding: spacing.lg,
        backgroundColor: colors.surface,
        border: `1px solid ${colors.border}`,
        borderRadius: radii.lg,
        boxShadow: "0 4px 12px rgba(0,0,0,0.05)",
    },
    title: {
        fontSize: fontSizes.xl,
        marginBottom: spacing.md,
        textAlign: "center",
        color: colors.text,
    },
    input: {
        padding: spacing.md,
        marginBottom: spacing.sm,
        borderRadius: radii.md,
        border: `1px solid ${colors.border}`,
        fontSize: fontSizes.md,
    },
    button: {
        padding: spacing.md,
        backgroundColor: colors.primary,
        color: "#fff",
        border: "none",
        borderRadius: radii.md,
        cursor: "pointer",
        fontSize: fontSizes.md,
        marginTop: spacing.sm,
    },
    linkText: {
        marginTop: spacing.sm,
        color: colors.primary,
        textAlign: "center",
        cursor: "pointer",
        fontSize: fontSizes.sm,
    },
};

export default LoginScreen;
