import React, { useEffect, useState } from "react";
import { jwtDecode } from "jwt-decode";
import { useNavigate } from "react-router-dom";

const API_URL = "http://localhost:8080/users"; // Web: localhost statt 10.0.2.2

const ProfileScreen = () => {
    const [user, setUser] = useState<{ username: string; email: string } | null>(null);
    const [loading, setLoading] = useState(true);
    const navigate = useNavigate();

    useEffect(() => {
        const fetchUserProfile = async () => {
            const token = localStorage.getItem("authToken");
            if (!token) return;

            try {
                const decoded: any = jwtDecode(token);
                const email = decoded.sub;

                const response = await fetch(`${API_URL}/email/${email}`, {
                    method: "GET",
                    headers: {
                        Authorization: `Bearer ${token}`,
                        "Content-Type": "application/json",
                    },
                });

                if (!response.ok) throw new Error("Fehler beim Laden");

                const data = await response.json();
                setUser(data);
            } catch (error) {
                console.error("Fehler beim Laden:", error);
            } finally {
                setLoading(false);
            }
        };

        fetchUserProfile();
    }, []);

    if (loading) return <div style={styles.loader}>Lade Profil...</div>;

    return (
        <div style={styles.container}>
            {/* Header */}
            <div style={styles.headerRow}>
                <h2 style={styles.welcomeText}>Hi, {user?.username || "User"}!</h2>
                <button
                    style={styles.settingsButton}
                    onClick={() => alert("Settings-Funktion folgt")}
                >
                    ⚙️
                </button>
            </div>

            {/* Bearbeiten */}
            <div style={{ marginTop: 30 }}>
                <button style={styles.editButton} onClick={() => navigate("/edit-profile")}>
                    Profil bearbeiten
                </button>
            </div>

            {/* Placeholder für Inhalte */}
            <div style={styles.placeholder}>
                <p>Hier kommen später Rezepte.</p>
            </div>
        </div>
    );
};

const styles: { [key: string]: React.CSSProperties } = {
    container: {
        maxWidth: "600px",
        margin: "50px auto",
        padding: "20px",
        border: "1px solid #ddd",
        borderRadius: "10px",
        backgroundColor: "#f9f9f9",
    },
    loader: {
        display: "flex",
        justifyContent: "center",
        alignItems: "center",
        height: "100vh",
        fontSize: "20px",
    },
    headerRow: {
        display: "flex",
        justifyContent: "space-between",
        alignItems: "center",
    },
    welcomeText: {
        fontSize: "24px",
        fontWeight: "bold",
    },
    settingsButton: {
        fontSize: "20px",
        background: "none",
        border: "none",
        cursor: "pointer",
    },
    editButton: {
        padding: "10px 20px",
        fontSize: "16px",
        backgroundColor: "#007bff",
        color: "#fff",
        border: "none",
        borderRadius: "5px",
        cursor: "pointer",
    },
    placeholder: {
        marginTop: 40,
        textAlign: "center",
        color: "#555",
    },
};

export default ProfileScreen;
