import {useEffect, useState} from "react";
import {Routes, Route, Navigate, Link} from "react-router-dom";
import {jwtDecode} from "jwt-decode";

import Home from "../screens/Home";
import LoginScreen from "../screens/LoginScreen";
import RegisterScreen from "../screens/RegisterScreen";
import Profile from "../screens/Profile";
import EditProfileScreen from "../screens/EditProfileScreen";
import LibraryScreen from "../screens/LibraryScreen";

import {MdHome, MdList, MdPerson} from "react-icons/md"; // Web Icons

// Token validieren mit localStorage
const isTokenValid = () => {
    const token = localStorage.getItem("authToken");
    if (!token) return false;

    try {
        const decoded: any = jwtDecode(token);
        return decoded.exp && decoded.exp > Math.floor(Date.now() / 1000);
    } catch (error) {
        return false;
    }
};

// Web-basierte BottomTabs
const BottomTabs = () => (
    <nav style={{display: "flex", gap: 20, justifyContent: "center", marginBottom: 20}}>
        <Link to="/"><MdHome size={24}/> Home</Link>
        <Link to="/library"><MdList size={24}/> Library</Link>
        <Link to="/profile"><MdPerson size={24}/> Profile</Link>
    </nav>
);

const AppNavigator = () => {
    const [isLoggedIn, setIsLoggedIn] = useState<boolean | null>(null);

    useEffect(() => {
        setIsLoggedIn(isTokenValid());
    }, []);

    if (isLoggedIn === null) {
        return (
            <div style={{textAlign: "center", marginTop: "2rem"}}>
                <p>Loading...</p>
            </div>
        );
    }

    if (!isLoggedIn) {
        return (
            <Routes>
                <Route path="/login" element={<LoginScreen/>}/>
                <Route path="/register" element={<RegisterScreen/>}/>
                <Route path="*" element={<Navigate to="/login"/>}/>
            </Routes>
        );
    }

    return (
        <>
            <BottomTabs/>
            <Routes>
                <Route path="/" element={<Home/>}/>
                <Route path="/library" element={<LibraryScreen/>}/>
                <Route path="/profile" element={<Profile/>}/>
                <Route path="/edit-profile" element={<EditProfileScreen/>}/>
                <Route path="*" element={<Navigate to="/"/>}/>
            </Routes>
        </>
    );
};

export default AppNavigator;
