const API_URL = "http://localhost:8080/api/auth";
export const loginUser = async (email: string, password: string) => {
    try {
        const response = await fetch(`${API_URL}/login`, {
            method: "POST",
            headers: {
                "Content-Type": "application/json"
            },
            body: JSON.stringify({email, password})
        });
        const data = await response.json();

        if (!response.ok) {
            throw new Error("Login fehlgeschlagen");
        }

        return data.token; // Token zurückgeben
    } catch (error) {
        console.error("Fehler beim Login:", error);
        return null;
    }
};
export const registerUser = async (email: string, password: string, username: string) => {
    try {
        // Die Daten, die an das Backend gesendet werden
        const userData = {email, password, username};

        // Anfrage an das Backend
        const response = await fetch(`${API_URL}/register`, {
            method: "POST",
            headers: {
                "Content-Type": "application/json",
            },
            body: JSON.stringify(userData),
        });

        // Überprüfen, ob die Antwort erfolgreich war
        if (!response.ok) {
            const errorMessage = await response.text();
            throw new Error(errorMessage); // Beispiel für Fehlermeldung, falls E-Mail oder Username bereits vergeben
        }

        return userData // Erfolgreiche Antwort, z.B. der neue User
    } catch (error) {
        console.error("Fehler bei der Registrierung:", error);
        throw error; // Fehler weitergeben, damit der Benutzer entsprechend reagieren kann
    }
};


